pub fn create_collection<T: Config>()Expand description
Create a collection owned by the signer.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::create_collection.
pub fn create_collection<T: Config>()Create a collection owned by the signer.
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::create_collection.