referrerpolicy=no-referrer-when-downgrade

delete_collection

Function delete_collection 

pub fn delete_collection<T: Config>(collection: CollectionId)
Delete an empty collection owned by the signer.

Every item definition and collection metadata entry must be removed first. Deleted collection identifiers are never reused.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::delete_collection.