referrerpolicy=no-referrer-when-downgrade

nominate_collection_owner

Function nominate_collection_owner 

pub fn nominate_collection_owner<T: Config>(
    collection: CollectionId,
    pending_owner: Option<T::AccountId>,
)
Nominate an account to claim ownership of a collection.

Only the current owner may nominate or clear a prospective owner. Nomination does not change authority or move deposits.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::nominate_collection_owner.