pub fn claim_collection_ownership<T: Config>(collection: CollectionId)Expand description
Claim a collection after nomination by its current owner.
An equivalent aggregate consideration is first created for the claimant and then the previous owner’s ticket is dropped. The operation is atomic: failure to establish the claimant’s consideration leaves ownership and both tickets unchanged.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::claim_collection_ownership.