pub fn set_collection_metadata<T: Config>(
collection: CollectionId,
key: MetadataKeyOf<T>,
value: Option<MetadataValueOf<T>>,
)Expand description
Set or remove a collection-level metadata default.
Only the collection owner may mutate metadata. None releases an existing entry’s
deposit; when the key is absent it is a successful no-op.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::set_collection_metadata.